@@ -9,9 +9,11 @@ from .busy import NodeBusyMixin
 from .shell import BaseShellMixin
 from .http import HttpClientMixin
 from .resources import ResourceManagerMixin
+from .background import BackgroundCoreMixin
 
 
-class BaseIoTNode(ResourceManagerMixin,
+class BaseIoTNode(BackgroundCoreMixin,
+                  ResourceManagerMixin,
                   HttpClientMixin,
                   BaseShellMixin,
                   NodeBusyMixin,
@@ -34,3 +36,6 @@ class BaseIoTNode(ResourceManagerMixin,
     def stop(self):
         super(BaseIoTNode, self).stop()
         self.log.info("Stopping Node with ID {id}", id=self.id)
+
+    def exit(self):
+        self.stop()
